@@ -21,6 +21,7 @@
 #               2024/11/05 - PH Added support for Google Maps "Export timeline data"
 #                               JSON format
 #               2025/09/22 - PH Added ability to read Columbus CSV  log files
+#               2026/01/24 - PH Added GeoUserTag feature
 #
 # References:   1) http://www.topografix.com/GPX/1/1/
 #               2) http://www.gpsinformation.org/dale/nmea.htm#GSA
@@ -35,7 +36,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:Public);
 use Image::ExifTool::GPS;
 
-$VERSION = '1.82';
+$VERSION = '1.85';
 
 sub JITTER() { return 2 }       # maximum time jitter
 
@@ -43,6 +44,7 @@ sub GetTime($);
 sub SetGeoValues($$;$);
 sub PrintFixTime($);
 sub PrintFix($@);
+sub InitUserTags($);
 
 # XML tags that we recognize (keys are forced to lower case)
 my %xmlTag = (
@@ -82,6 +84,8 @@ my %xmlTag = (
     placemark   => '',          # KML
 );
 
+my %userTag;    # user-defined XML tags
+
 # fix information keys which must be interpolated around a circle
 my %cyclical = (lon => 1, track => 1, dir => 1, pitch => 1, roll => 1);
 my %cyc180 = (lon => 1, pitch => 1, roll => 1); # wraps from 180 to -180
@@ -174,6 +178,8 @@ sub LoadTrackLog($$;$)
     unless (eval { require Time::Local }) {
         return 'Geotag feature requires Time::Local installed';
     }
+    InitUserTags($et);
+
     # add data to existing track
     my $geotag = $et->GetNewValue('Geotag') || { };
 
@@ -357,16 +363,24 @@ sub LoadTrackLog($$;$)
 # XML format (GPX, KML, Garmin XML/TCX etc)
 #
         if ($format eq 'XML') {
-            my ($arg, $tok, $td);
-            s/\s*=\s*(['"])\s*/=$1/g;  # remove unnecessary white space in attributes
-            # Workaround for KML generated by Google Location History:
-            # lat/lon/alt are space-separated; we want commas.
-            s{(\S+)\s+(\S+)\s+(\S+)(</gx:coord>)}{$1,$2,$3$4};
-            foreach $arg (split) {
+            my (@args, $arg, $tok, $td, $value);
+            if (/^([^<]+<\/[^>]+>)/) {
+                # handle simple property
+                s/^\s+</</; # remove whitespace if only whitespace before "<"
+                # Workaround for KML generated by Google Location History:
+                # lat/lon/alt are space-separated; we want commas.
+                s{(\S+)\s+(\S+)\s+(\S+)(</gx:coord>)}{$1,$2,$3$4};
+                push @args, $_;
+            } else {
+                # handle property with attributes
+                s/\s*=\s*(['"])\s*/=$1/g;   # remove unnecessary white space in attributes
+                push @args, split;
+            }
+            foreach $arg (@args) {
                 # parse attributes (eg. GPX 'lat' and 'lon')
                 # (note: ignore namespace prefixes if they exist)
                 if ($arg =~ /^(\w+:)?(\w+)=(['"])(.*?)\3/g) {
-                    my $tag = $xmlTag{lc $2};
+                    my $tag = $xmlTag{lc $2} || $userTag{lc $2};
                     if ($tag) {
                         $$fix{$tag} = $4;
                         if ($keyCategory{$tag}) {
@@ -382,7 +396,8 @@ sub LoadTrackLog($$;$)
                 }
                 # loop through XML elements
                 while ($arg =~ m{([^<>]*)<(/)?(\w+:)?(\w+)(>|$)}g) {
-                    my $tag = $xmlTag{$tok = lc $4};
+                    $tok = lc $4;
+                    my $tag = $xmlTag{$tok} || $userTag{$tok};
                     # parse as a simple property if this element has a value
                     if (defined $tag and not $tag) {
                         # a containing property was opened or closed
@@ -1137,20 +1152,20 @@ sub SetGeoValues($$;$)
             my $p1 = $$points{$t1};
             # check to see if we are extrapolating before the first entry in a track
             my $maxSecs = ($$p1{first} and $geoMaxIntSecs) ? $geoMaxExtSecs : $geoMaxIntSecs;
+            my $tn; # find time of nearest fix
+            if ($time - $t0 < $t1 - $time) {
+                $tn = $t0;
+                $iExt = $i0;
+            } else {
+                $tn = $t1;
+                $iExt = $i1;
+            }
             # don't interpolate if fixes are too far apart
             # (but always interpolate fixes inside the same TimeSpan)
             if ($t1 - $t0 > $maxSecs and (not $$p1{span} or not $$points{$t0}{span} or
                 $$p1{span} != $$points{$t0}{span}))
             {
                 # treat as an extrapolation -- use nearest fix if close enough
-                my $tn;
-                if ($time - $t0 < $t1 - $time) {
-                    $tn = $t0;
-                    $iExt = $i0;
-                } else {
-                    $tn = $t1;
-                    $iExt = $i1;
-                }
                 if (abs($time - $tn) > $geoMaxExtSecs) {
                     $err or $err = 'Time is too far from nearest GPS fix';
                     $et->VPrint(2, '  Nearest fix:     ', PrintFixTime($tn), ' (',
@@ -1167,6 +1182,8 @@ sub SetGeoValues($$;$)
                 $et->VPrint(2, "  Interpolating between fixes (f=$f0):\n",
                     PrintFix($points, $t0, $t1)) if $verbose > 2;
                 $fix = { };
+                # copy user-defined tags from nearest fix
+                $$fix{$_} = $$points{$tn}{$_} foreach values %userTag;
                 # loop through available fix information categories
                 # (pos, track, alt, orient)
                 my ($category, $key);
@@ -1269,7 +1286,7 @@ Category:       foreach $category (qw{pos track alt orient atemp err dop}) {
             my $tag = ($$nvHash{WantGroup} ? "$$nvHash{WantGroup}:" : '') . 'Geolocate';
             # pass along any regular expressions to qualify geolocation search
             my $parms = join ',', grep m(/), split /\s*,\s*/, $geoloc;
-            $parms and $parms = ",$parms,both"; 
+            $parms and $parms = ",$parms,both";
             $et->SetNewValue($tag => "$$fix{lat},$$fix{lon}$parms");
             # (the Geolocate tag will be restored to its original value
             # by RestoreNewValues before the next file in batch processing)
@@ -1345,6 +1362,23 @@ Category:       foreach $category (qw{pos track alt orient atemp err dop}) {
             if (defined $dop) {
                 $et->SetNewValue(GPSMeasureMode => $mm, %opts);
                 $et->SetNewValue(GPSDOP => $dop, %opts);
+                # also set GPSHPositioningError if specified
+                my $hposErr = $$et{OPTIONS}{GeoHPosErr};
+                if ($hposErr) {
+                    $hposErr =~ s/gpsdop/GPSDOP/i;
+                    my $GPSDOP = $dop;
+                    local $SIG{'__WARN__'} = \&Image::ExifTool::SetWarning;
+                    undef $Image::ExifTool::evalWarning;
+                    #### eval GeoHPosErr ($GPSDOP)
+                    $hposErr = eval $hposErr;
+                    my $err = Image::ExifTool::GetWarning() || $@;
+                    if ($err) {
+                        $err = Image::ExifTool::CleanWarning($err);
+                        $et->Warn("Error calculating GPSHPositioningError: $err", 1);
+                    } else {
+                        $et->SetNewValue(GPSHPositioningError => $hposErr, %opts);
+                    }
+                }
             }
         }
         unless ($xmp) {
@@ -1362,11 +1396,19 @@ Category:       foreach $category (qw{pos track alt orient atemp err dop}) {
         unless ($exif) {
             @r = $et->SetNewValue(GPSDateTime => "$gpsDate $gpsTime", %opts);
         }
+        # set user-defined tags
+        foreach (sort values %userTag) {
+            @r = $et->SetNewValue(substr($_, 1) => $$fix{$_}) if defined $$fix{$_};
+        }
     } else {
         my %opts = ( IgnorePermanent => 1 );
         $opts{Replace} = 2 if defined $val; # remove existing new values
+        # reset user-defined GPX tags
+        InitUserTags($et);  # (won't be set yet because we didn't read a GPX file)
+        foreach (values %userTag) {
+            my @r = $et->SetNewValue(substr($_, 1), undef, %opts);
+        }
         $opts{Group} = $writeGroup if $writeGroup;
-
         # reset any GPS values we might have already set
         foreach (qw(GPSLatitude GPSLatitudeRef GPSLongitude GPSLongitudeRef
                     GPSAltitude GPSAltitudeRef GPSDateStamp GPSTimeStamp GPSDateTime
@@ -1513,7 +1555,7 @@ sub PrintFixTime($)
 {
     my $time = $_[0] + 0.0005;  # round off to nearest ms
     my $fsec = int(($time - int($time)) * 1000);
-    return sprintf('%s.%.3d UTC', Image::ExifTool::ConvertUnixTime($time), $fsec);
+    return Image::ExifTool::ConvertUnixTime($time, undef, 3) . ' UTC';
 }
 
 #------------------------------------------------------------------------------
@@ -1539,6 +1581,22 @@ sub PrintFix($@)
     return $str;
 }
 
+#------------------------------------------------------------------------------
+# Initialize %userTag for reading user-defined GPX tags
+# Inputs: 0) ExifTool ref
+sub InitUserTags($)
+{
+    my $et = shift;
+    %userTag = ( );
+    if ($$et{OPTIONS}{GeoUserTag}) {
+        foreach (split /\s*,\s*/, $$et{OPTIONS}{GeoUserTag}) {
+            next unless /^(.+)=(.+)$/;
+            $xmlTag{lc $2} and $et->Warn("User-defined GPX tag '${2}' conflicts with existing tag"), next;
+            $userTag{lc $2} = "_$1";    # (leading underline prevents conflicts)
+        }
+    }
+}
+
 #------------------------------------------------------------------------------
 1;  # end
 
@@ -1573,7 +1631,7 @@ user-defined tag GPSRoll, must be active.
 
 =head1 AUTHOR
 
-Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2026, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
