@@ -11,7 +11,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool;
 
-$VERSION = '1.04';
+$VERSION = '1.00';
 
 sub ProcessLigoGPS($$$;$);
 sub ProcessLigoJSON($$$);
@@ -173,9 +173,7 @@ sub DecipherLigoGPS($$$;$)
             $$next{$ch1} = [ $ch2 ];
         }
         # must wait until the lookup contains all 10 digits
-        scalar(keys %$next) < 10 and return 1;
-        # protect against trying to decipher bad data
-        scalar(keys %$next) > 10 and $$cipherInfo{'next'} = { }, return 1;
+        return 1 if scalar(keys %$next) < 10;
         my (@order, $two);
         return 1 unless OrderCipherDigits($ch1, $next, \@order);
         # get index of enciphered "2" in ordered array
@@ -257,33 +255,18 @@ sub ParseLigoGPS($$$;$)
     $et->HandleTag($tagTbl, 'GPSLongitude', $lon * (($lonNeg or $lonRef eq 'W') ? -1 : 1));
     $et->HandleTag($tagTbl, 'GPSSpeed',     $spd * $spdScl);
     $et->HandleTag($tagTbl, 'GPSTrack', $1) if $str =~ /\bA:(\S+)/;
-    $et->HandleTag($tagTbl, 'GPSAltitude', $1) if $str =~ /\bH:(\S+)/;
-    $et->HandleTag($tagTbl, 'MagneticVariation', $1) if $str =~ /\bM:(\S+)/;
     # (have a sample where tab is used to separate acc components)
     $et->HandleTag($tagTbl, 'Accelerometer',"$1 $2 $3") if $str =~ /x:(\S+)\sy:(\S+)\sz:(\S+)/;
+    $et->HandleTag($tagTbl, 'M', $1) if $str =~ /\bM:(\S+)/;
+    $et->HandleTag($tagTbl, 'H', $1) if $str =~ /\bH:(\S+)/;
     delete $$et{SET_GROUP1};
 }
 
-#------------------------------------------------------------------------------
-# Process GKU dashcam trailer containing JSON-format LigoGPS
-# Inputs: 0) ExifTool ref, 1) dirInfo ref, 2) tag table ref
-# Returns: 1 on success
-sub ProcessGKU($$$;$)
-{
-    my ($et, $dirInfo, $tagTbl) = @_;
-    my $dataPt = $$dirInfo{DataPt};
-    my $pos = unpack('V', $$dataPt);
-    return 0 if $pos + 13 > length $$dataPt or substr($$dataPt, $pos, 13) ne 'LIGOGPSINFO {';
-    pos($$dataPt) = $pos;
-    return ProcessLigoJSON($et, $dirInfo, $tagTbl);
-}
-
 #------------------------------------------------------------------------------
 # Process LIGOGPSINFO data (non-JSON format)
 # Inputs: 0) ExifTool object ref, 1) dirInfo ref, 2) tag table ref
 #         3) 1=LIGOGPS lat/lon/spd weren't fuzzed
 # Returns: 1 on success
-# Notes:  The directory data should start with the string "LIGOGPSINFO\0"
 sub ProcessLigoGPS($$$;$)
 {
     my ($et, $dirInfo, $tagTbl, $noFuzz) = @_;
@@ -329,7 +312,7 @@ sub ProcessLigoJSON($$$)
     my $dataPt = $$dirInfo{DataPt};
     my $dirLen = $$dirInfo{DirLen};
     require Image::ExifTool::Import;
-    $et->VerboseDir('LIGO_JSON', undef, length($$dataPt) - pos($$dataPt));
+    $et->VerboseDir('LIGO_JSON', undef, length($$dataPt));
     $$et{SET_GROUP1} = 'LIGO';
     while ($$dataPt =~ /LIGOGPSINFO (\{.*?\})/g) {
         my $json = $1;
